tietools.label_tie_chains_in_expr_with_written_tie_chain_duration
=================================================================

.. autofunction:: abjad.tools.tietools.label_tie_chains_in_expr_with_written_tie_chain_duration
